@@ -109,7 +109,7 @@ def push(
     if labels is not None:
         for k, v in labels.items():
             args.append("-l")
-            args.append(f"{k}={v}")
+            args.append(f'{k}="{v}"')
 
     if refs is not None:
         args.append("-l")
